//[mahjong-utils](../../index.md)/[mahjongutils.shanten](index.md)/[validate](validate.md)

# validate

[common]\
fun [CommonShantenArgs](-common-shanten-args/index.md).[validate](validate.md)(): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[CommonShantenArgsErrorInfo](-common-shanten-args-error-info/index.md)&gt;

fun [FuroChanceShantenArgs](-furo-chance-shanten-args/index.md).[validate](validate.md)(): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[FuroChanceShantenArgsErrorInfo](-furo-chance-shanten-args-error-info/index.md)&gt;
